@@ -1,6 +1,5 @@
 import json
 
-from .api_call import api_call
 from .device import Device
 from .entity import Entity
 from .zone import Zone
@@ -54,7 +53,7 @@ class Account(Entity):
             platform (str): Device platform.
         """
 
-        response = api_call(
+        response = self.api.call(
             "POST",
             "/accounts/{}/devices".format(self._id),
             data={
@@ -78,11 +77,11 @@ class Account(Entity):
             device_id (str): Device ID.
         """
 
-        device_data = api_call("GET", "/accounts/{}/devices/{}".format(self._id, device_id))
+        device_data = self.api.call("GET", "/accounts/{}/devices/{}".format(self._id, device_id))
         if not device_data:
             return None
 
-        device = Device(device_data["device"], device_data)
+        device = Device(device_data["device"], device_data, api=self.api)
         return device
 
     def get_devices(self, attributes=None, zones=None, include_subzones=None):
@@ -97,18 +96,18 @@ class Account(Entity):
         if include_subzones is not None:
             params["include_subzones"] = json.dumps(include_subzones)
 
-        result = api_call("GET", "/accounts/{}/devices".format(self._id), params=params)
+        result = self.api.call("GET", "/accounts/{}/devices".format(self._id), params=params)
         if not isinstance(result, list):
             raise ValueError("API returned incorrect type")
-        return [Device(device_data["device"], device_data) for device_data in result]
+        return [Device(device_data["device"], device_data, api=self.api) for device_data in result]
 
     def get_zones(self):
         """:obj:`list` of :obj:`Zone`: Fetch a list of all zones in the account.
         """
-        result = api_call("GET", "/accounts/{}/zones".format(self._id))
+        result = self.api.call("GET", "/accounts/{}/zones".format(self._id))
         if not result:
             return []
-        return [Zone(data['id'], data) for data in result]
+        return [Zone(data['id'], data, api=self.api) for data in result]
 
     @property
     def email(self):
@@ -158,7 +157,7 @@ class Account(Entity):
         if utc_end is not None:
             params['utc_end'] = utc_end
 
-        data = api_call(
+        data = self.api.call(
             "GET",
             "/accounts/{}/statistics/csv".format(self._id),
             raw=True,
