@@ -162,7 +162,7 @@ class Device(Entity):
 
         return response
 
-    def data(self, start=None, end=None, topics=None, direction="forward"):
+    def data(self, start=None, end=None, topics=None, direction="forward", **params):
         """iter: Fetches data from the robot for a specified interval and returns an iterator
         to page through the data. Each next() call to the iterator will return 1 message, and
         data will be fetched from the server as necessary until the end has been reached.
@@ -173,8 +173,6 @@ class Device(Entity):
             topics (`list` of `str`): List of topics of interest (in most cases, ROS topics).
             direction (str): "forward" or "backward".
         """
-
-        params = {}
         if start is not None:
             params["utc_start"] = to_unix_time(start)
             if end is None:
